The Foos and The Bars - python

1. # Static Sites on Heroku Cedar

   Heroku's excellent Cedar Stack has first-class support for Python, Ruby, Node.js, Java, Clojure, and Scala applications. Unfortunately, there's no obvious way to serve static sites without first fronting them with a Rack or WSGI application.

   The Cedar stack has unofficial support for Custom Build Packs, which allow ...

   Read more

2. # I Use This

   A while back, I published a post about my setup, inspired by the awesome articles on the UsesThis site.

   As times change, so does my toolset. So, here's a list of my latest favorite things. I love them, and think you should use them too.

   ## ep.io

   Perfectly Pythonic ...

   Read more

3. # New Blog: Finally Static!

   I've been wanting to convert my website from a WordPress-powered application to a static one for a long time now. I tried a few different systems, but nothing was flexible enough for my needs.

   I almost sat down and wrote something myself, but luckly I found Alex Metaireau's ...

   Read more

## blogroll

- About
- Resume

## social

- atom feed
- GitHub
- Twitter